%{!?scl_name_base:%global scl_name_base thermostat}
%{!?scl_name_version:%global scl_name_version 1}

%{!?scl:%global scl %{scl_name_base}%{scl_name_version}}
%scl_package %scl

# do not produce empty debuginfo package
%global debug_package %{nil}

Name:       %scl_name
Version:    1.1
Release:    4%{?dist}
Summary:    Package that installs %scl

License:    GPLv2+
#URL:
Source1:    macros.thermostat1
Source2:    thermostat1-javapackages-provides-wrapper
Source3:    thermostat1-javapackages-requires-wrapper
Source4:    README
Source5:    LICENSE

# This needs to require all packages shipped with the thermostat1
# collection. The leaf package is thermostat1-thermostat-webapp
# which should pull in thermostat1-thermostat plus all deps, such
# as mongo-java-driver and mongodb from the mongodb collection.
# See RHBZ#1033653 for an explanation as to why thermostat-webapp
# and not thermostat without webapp.
BuildRequires:    scl-utils-build
BuildRequires:    help2man
Requires:         %{scl_prefix}thermostat-webapp
Requires:         %{name}-runtime

%description
This is the main package for the %scl Software Collection.

%package common
# xmvn config is set up so as to check collections in order:
# thermostat1 -> mongodb24 -> base
# Since thermostat1 packages can do ". /opt/rh/mongodb24/enable"
# make sure this file is there by requiring the owning package.
Requires:         mongodb24 >= 1-2
Summary:          Package containing common parts of %{scl}-runtime and %{scl}-build sub packages.

%description common
%{summary}

%package runtime
Summary:    Package that handles %scl Software Collection.
Requires:   scl-utils >= 20120927-8
Requires:   %{name}-common = %{version}-%{release}

%description runtime
Package shipping essential scripts to work with the %scl Software Collection.

%package build
Requires:   scl-utils >= 20120927-8
Requires:   %{name}-common = %{version}-%{release}
Requires:   java-1.7.0-openjdk-devel
Summary:    Build support tools for the %scl Software Collection.

# Provide this build-time-only
Provides:   java = 1:1.7.0

%description build
Package shipping essential configuration marcros/files in order to be able
to build %scl Software Collection.

%package scldevel
Summary: Package shipping development files for %scl.
Group: Applications/File

%description scldevel
Development files for %scl (useful e.g. for hierarchical collection
building with transitive dependencies).

%prep
%setup -c -T
#===================#
# SCL enable script #
#===================#
cat <<EOF >enable
# The thermostat1 collection depends on the mongodb24 collection
# for the mongo-java-driver. We need to source the enable script
# in order for xmvn builds to work.
. scl_source enable mongodb24 

# Generic variables
export PATH="%{_bindir}:\${PATH:-/bin:/usr/bin}"
export MANPATH="%{_mandir}:\${MANPATH}"

# Needed by Java Packages Tools to locate java.conf
export JAVACONFDIRS="%{_sysconfdir}/java:\${JAVACONFDIRS:-/etc/java}"

# Required by XMvn to locate its configuration file(s)
export XDG_CONFIG_DIRS="%{_sysconfdir}/xdg:\${XDG_CONFIG_DIRS:-/etc/xdg}"

# Not really needed by anything for now, but kept for consistency with
# XDG_CONFIG_DIRS.
export XDG_DATA_DIRS="%{_datadir}:\${XDG_DATA_DIRS:-/usr/local/share:/usr/share}"
EOF

#===========#
# java.conf #
#===========#
cat <<EOF >java.conf
# Java configuration file for %{scl} software collection.
JAVA_LIBDIR=%{_javadir}
JNI_LIBDIR=%{_jnidir}
JVM_ROOT=%{_jvmdir}
EOF

#=============#
# XMvn config #
#=============#
cat <<EOF >configuration.xml
<!-- XMvn configuration file for %{scl} software collection -->
<configuration>
  <resolverSettings>
    <prefixes>
      <prefix>/opt/rh/%{scl}/root</prefix>
    </prefixes>
  </resolverSettings>
  <installerSettings>
    <metadataDir>opt/rh/%{scl}/root/usr/share/maven-fragments</metadataDir>
  </installerSettings>
  <repositories>
    <repository>
      <id>%{scl}-resolve</id>
      <type>compound</type>
      <properties>
        <prefix>opt/rh/%{scl}/root</prefix>
        <namespace>%{scl}</namespace>
      </properties>
      <configuration>
        <repositories>
          <!-- %{scl} depends on the mongodb24 collection. This needs
               to be expressed in the xmvn repo config. -->
          <repository>mongodb24-resolve</repository>
          <repository>base-resolve</repository>
        </repositories>
      </configuration>
    </repository>
    <repository>
      <id>resolve-system</id>
      <type>compound</type>
      <properties>
        <prefix>/</prefix>
      </properties>
      <configuration>
        <repositories>
          <repository>%{scl}-resolve</repository>
          <repository>mongodb24-resolve</repository>
          <repository>base-resolve</repository>
        </repositories>
      </configuration>
    </repository>
    <repository>
      <id>install</id>
      <type>compound</type>
      <properties>
        <prefix>opt/rh/%{scl}/root</prefix>
        <namespace>%{scl}</namespace>
      </properties>
      <configuration>
        <repositories>
          <repository>base-install</repository>
        </repositories>
      </configuration>
    </repository>
    <repository>
      <id>install-raw-pom</id>
      <type>compound</type>
      <properties>
        <prefix>opt/rh/%{scl}/root</prefix>
        <namespace>%{scl}</namespace>
      </properties>
      <configuration>
        <repositories>
          <repository>base-raw-pom</repository>
        </repositories>
      </configuration>
    </repository>
    <repository>
      <id>install-effective-pom</id>
      <type>compound</type>
      <properties>
        <prefix>opt/rh/%{scl}/root</prefix>
        <namespace>%{scl}</namespace>
      </properties>
      <configuration>
        <repositories>
          <repository>base-effective-pom</repository>
        </repositories>
      </configuration>
    </repository>
  </repositories>
</configuration>
EOF

#=====================#
# README and man page #
#=====================#
# This section generates README file from a template and creates man page
# from that file, expanding RPM macros in the template file.
cat >README <<'EOF'
%{expand:%(cat %{SOURCE4})}
EOF

# copy the license file so %%files section sees it
cp %{SOURCE5} .

# scldevel macros
cat << EOF > macros.%{scl_name_base}-scldevel
%%scl_%{scl_name_base} %{scl}
%%scl_prefix_%{scl_name_base} %{scl_prefix}
EOF

%build
# generate a helper script that will be used by help2man
cat >h2m_helper <<'EOF'
#!/bin/bash
[ "$1" == "--version" ] && echo "%{scl_name} %{version} Software Collection" || cat README
EOF
chmod a+x h2m_helper

# generate the man page
help2man -N --section 7 ./h2m_helper -o %{scl_name}.7


%install
# Parentheses are needed here as workaround for rhbz#1017085
(%scl_install)

install -d -m 755 %{buildroot}%{_scl_scripts}
install -p -m 755 enable %{buildroot}%{_scl_scripts}/

install -d -m 755 %{buildroot}%{_sysconfdir}/java
install -p -m 644 java.conf %{buildroot}%{_sysconfdir}/java/

install -d -m 755 %{buildroot}%{_sysconfdir}/xdg/xmvn
install -p -m 644 configuration.xml %{buildroot}%{_sysconfdir}/xdg/xmvn/

# install rpm magic
install -Dpm0644 %{SOURCE1} %{buildroot}%{_root_sysconfdir}/rpm/macros.%{name}
install -Dpm0755 %{SOURCE2} %{buildroot}%{_rpmconfigdir}/%{name}-javapackages-provides-wrapper
install -Dpm0755 %{SOURCE3} %{buildroot}%{_rpmconfigdir}/%{name}-javapackages-requires-wrapper

# Create java/maven/icons directories so that they'll get properly owned.
# These are listed in the scl_files macro. See also: RHBZ#1057169
mkdir -p %{buildroot}%{_javadir}
mkdir -p %{buildroot}%{_prefix}/lib/java
mkdir -p %{buildroot}%{_javadocdir}
mkdir -p %{buildroot}%{_mavenpomdir}
mkdir -p %{buildroot}%{_datadir}/maven-effective-poms
mkdir -p %{buildroot}%{_mavendepmapfragdir}
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps

# install generated man page
mkdir -p %{buildroot}%{_mandir}/man7/
install -m 644 %{scl_name}.7 %{buildroot}%{_mandir}/man7/%{scl_name}.7

# scldevel macro
install -p -m 644 macros.%{scl_name_base}-scldevel %{buildroot}%{_root_sysconfdir}/rpm/

# Empty package (no file content).  The sole purpose of this package
# is collecting its dependencies so that the whole SCL can be
# installed by installing %{name}.
%files

# Runtime doesn't have files, they are owned by the shared subpackage.
# Why? Because we need enable and other config files in the build package
# as well. It would be bad for build to require runtime.
%files runtime
%doc README
%{_mandir}/man7/%{scl_name}.*

%files common
%doc LICENSE
%{scl_files}
%{_sysconfdir}/java/java.conf
%{_sysconfdir}/xdg/xmvn/configuration.xml

%files build
%{_root_sysconfdir}/rpm/macros.%{scl}-config
%{_root_sysconfdir}/rpm/macros.%{name}
%{_rpmconfigdir}/%{name}*

%files scldevel
%{_root_sysconfdir}/rpm/macros.%{scl_name_base}-scldevel

%changelog
* Mon Mar 31 2014 Honza Horak <hhorak@redhat.com> - 1.1-4
- Fix path typo in README
  Related: #1061461

* Thu Feb 13 2014 Omair Majid <omajid@redhat.com> - 1.1-3
- Update README
- Resolves: RHBZ#1061461

* Wed Feb 12 2014 Severin Gehwolf <sgehwolf@redhat.com> - 1.1-2
- Introduce scldevel subpackage.
- Resolves: RHBZ#1063360

* Wed Feb 12 2014 Omair Majid <omajid@redhat.com> - 1.1-1
- Add LICENSE, README and man page
- Bump version to 1.1
- Resolves: RHBZ#1061461

* Mon Jan 27 2014 Severin Gehwolf <sgehwolf@redhat.com> - 1-18
- Own common java/maven/icon directories for this scl.
- Resolves: RHBZ#1057169

* Wed Jan 15 2014 Severin Gehwolf <sgehwolf@redhat.com> - 1-17
- Depend on minimal scl-utils version which contains
  the scl_source file.
- Include release in requires for thermostat1-common.
- Resolves: RHBZ#1051576

* Wed Dec 18 2013 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1-16
- Remove osgi provides/requires generation
- Resolves: RHBZ#1042888

* Wed Dec 18 2013 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1-15
- Fix javadoc requires/provides generation
- Resolves: RHBZ#1042912

* Fri Dec 13 2013 Severin Gehwolf <sgehwolf@redhat.com> - 1-14
- Make the thermostat1 metapackage depend on webapp.
- Resolves: RHBZ#891540. 

* Wed Nov 27 2013 Severin Gehwolf <sgehwolf@redhat.com> - 1-13
- Properly source dependent mongodb24 SCL. 

* Wed Nov 27 2013 Severin Gehwolf <sgehwolf@redhat.com> - 1-13
- Properly source dependent mongodb24 SCL. 

* Wed Nov 27 2013 Omair Majid <omajid@redhat.com> - 1-12
- Provide java = 1:1.7.0 in -build just in case the openjdk package
  doesn't.

* Thu Nov 21 2013 Severin Gehwolf <sgehwolf@redhat.com> - 1-11
- Use java-1.7.0-openjdk-devel over java7-devel in Requires of build
  subpackage.

* Fri Nov 15 2013 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1-10
- Add java7-devel to Requires of build subpackage

* Wed Nov 13 2013 Severin Gehwolf <sgehwolf@redhat.com> - 1-9
- Re-enable mongodb24 dependency.

* Tue Nov 12 2013 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1-8
- Disable mongodb dependency for now (rhbz#1029128)

* Mon Nov 11 2013 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1-7
- Add provides and requires generator wrapper

* Mon Nov 11 2013 Severin Gehwolf <sgehwolf@redhat.com> 1-6
- Enable the mongodb24 collection in the thermostat1
  enable scriptlet.

* Thu Nov 07 2013 Severin Gehwolf <sgehwolf@redhat.com> 1-5
- Fix xmvn repo dependency on mongodb24 collection.

* Fri Oct 25 2013 Severin Gehwolf <sgehwolf@redhat.com> 1-4
- Move essential files into common subpackage.

* Fri Oct 25 2013 Severin Gehwolf <sgehwolf@redhat.com> 1-3
- First version including Java SCL configs.

* Tue Sep 24 2013 Severin Gehwolf <sgehwolf@redhat.com> 1-2
- Bump release for rebuild.

* Mon Jul 29 2013 Omair Majid <omajid@redhat.com> 1-1
- Initial package
